@@ -4,6 +4,7 @@ ljr11 <- function(y,n,tm,X=NULL,ofst=0,R=1000)
  m=ncol(X)
  if (is.null(m)) 
   m=0
+ or.ofst=ofst
  if (length(ofst)==1)
   ofst=as.double(rep(ofst,N))
  else
@@ -21,7 +22,7 @@ ljr11 <- function(y,n,tm,X=NULL,ofst=0,R=1000)
   m.variables=NULL
  m.variables=c('Intercept',m.variables)
  t.variables=c('t','max(t-tau1,0)')
-  if ((ofst[1]==0)&(length(ofst)==1))
+  if ((or.ofst[1]==0)&(length(or.ofst)==1))
    cat('eta=b0')
   else
    cat('eta=ofst+b0')
